@@ -1,9 +1,5 @@
-"""
-This model calculates the scarcity weighted water use based on the geospatial AWARE model
-(see UNEP (2016); Boulay et al (2016); Boulay et al (2020); EC-JRC (2017)).
-"""
 from hestia_earth.schema import SiteSiteType
-from hestia_earth.utils.lookup import download_lookup, _get_single_table_value, column_name, get_table_value
+from hestia_earth.utils.lookup import download_lookup, _get_single_table_value, column_name
 from hestia_earth.utils.tools import safe_parse_float
 
 from hestia_earth.models.log import logRequirements, debugMissingLookup, logShouldRun
@@ -13,6 +9,7 @@ from hestia_earth.models.utils.impact_assessment import (
     convert_value_from_cycle, emission_value, get_product, get_site, get_region_id
 )
 from hestia_earth.models.utils.input import sum_input_impacts
+from hestia_earth.models.utils.lookup import get_region_lookup_value
 from . import MODEL
 
 REQUIREMENTS = {
@@ -40,8 +37,8 @@ RETURNS = {
 }
 LOOKUPS = {
     "@doc": "Different lookup files are used depending on the situation",
-    "awareWaterBasinId": "using `awareWaterBasinId` and `YR_IRRI` (for `cropland`, `glass or high accessible cover`, or `permanent pasture`) or `YR_NONIRRI`",  # noqa: E501
-    "region-aware-factors": "using `region` and `YR_IRRI` (for `cropland`, `glass or high accessible cover` or `permanent pasture`) or `YR_NONIRRI`"  # noqa: E501
+    "awareWaterBasinId": "",
+    "region-aware-factors": ""
 }
 TERM_ID = 'scarcityWeightedWaterUse'
 AWARE_KEY = 'awareWaterBasinId'
@@ -71,11 +68,9 @@ def _get_factor_from_region(impact_assessment: dict, site: dict):
     region_id = get_region_id(impact_assessment)
     site_type = site.get('siteType')
     lookup_name = 'region-aware-factors.csv'
-    lookup = download_lookup(lookup_name)
     lookup_suffix = 'unspecified' if not site_type else ('irri' if site_type in IRRIGATED_SITE_TYPES else 'non_irri')
     column = f"Agg_CF_{lookup_suffix}"
-    value = get_table_value(lookup, 'termid', region_id, column_name(column))
-    debugMissingLookup(lookup_name, 'termid', region_id, column, value, model=MODEL, term=TERM_ID)
+    value = get_region_lookup_value(lookup_name, region_id, column, model=MODEL, term=TERM_ID)
     return safe_parse_float(value, None)
 
 
