@@ -2,7 +2,7 @@ from functools import reduce
 from enum import Enum
 from pydash.objects import merge
 from hestia_earth.utils.api import download_hestia
-from hestia_earth.utils.tools import flatten
+from hestia_earth.utils.tools import flatten, non_empty_list
 
 from .log import logger
 from .utils import CACHE_KEY, cached_value
@@ -30,14 +30,24 @@ _VALUE_AS_PARAM = {
 }
 
 
+def _value_as_param(param_type: ParamType = None): return _VALUE_AS_PARAM.get(param_type, lambda *args: None)
+
+
 def _cache_results(results: list, collections: list, index: int):
     start = index * len(collections)
     end = start + len(collections)
     return cache_site_results(results[start:end], collections)
 
 
-def _run_values(sites: list, param_type: ParamType, rasters: list = [], vectors: list = [], years: list = None):
-    param_values = list(map(_VALUE_AS_PARAM.get(param_type), sites))
+def _run_values(
+    sites: list,
+    param_type: ParamType = None,
+    rasters: list = [],
+    vectors: list = [],
+    years: list = None
+):
+    get_param_values = _value_as_param(param_type)
+    param_values = non_empty_list(map(get_param_values, sites))
     # unique list
     param_values = list(set(param_values)) if param_type == ParamType.GADM_IDS else list({
         str(v): v for v in param_values
@@ -59,18 +69,18 @@ def _run_values(sites: list, param_type: ParamType, rasters: list = [], vectors:
         site, area_size = site_values
 
         # get real index in values to handle duplicates
-        param_value = _VALUE_AS_PARAM.get(param_type)([site])
-        index = param_values.index(param_value)
+        param_value = get_param_values([site])
+        index = param_values.index(param_value) if param_value is not None else None
 
-        cached_data = {
+        cached_data = ({
             **_cache_results(raster_results, rasters, index),
             **_cache_results(vector_results, vectors, index)
-        } | ({CACHE_AREA_SIZE: area_size} if area_size is not None else {})
+        } if index is not None else {}) | ({CACHE_AREA_SIZE: area_size} if area_size is not None else {})
         cached_data = merge(cached_value(site, CACHE_GEOSPATIAL_KEY, {}), cached_data)
         site_cache = merge(
             site.get(CACHE_KEY, {}),
             {CACHE_GEOSPATIAL_KEY: cached_data},
-            ({CACHE_YEARS_KEY: cached_value(site, CACHE_YEARS_KEY, []) + years} if years else {})
+            ({CACHE_YEARS_KEY: list(set(cached_value(site, CACHE_YEARS_KEY, []) + years))} if years else {})
         )
         return merge(site, {CACHE_KEY: site_cache})
 
@@ -96,33 +106,46 @@ def _group_sites(sites: dict, check_has_cache: bool = True):
         (n, ) + (_should_run(n, area_size=get_region_area_size(n), check_has_cache=check_has_cache)) for n in sites
     ]
     # restrict sites based on should_cache result
-    sites = [(site, area_size) for site, should_cache, area_size in sites if should_cache]
+    sites_run = [(site, area_size) for site, should_cache, area_size in sites if should_cache]
+    # will only cache area and years
+    sites_no_run = [(site, area_size) for site, should_cache, area_size in sites if not should_cache]
 
     with_coordinates = [
-        (site, area_size) for site, area_size in sites if has_coordinates(site)
+        (site, area_size) for site, area_size in sites_run if has_coordinates(site)
     ]
     with_boundaries = [
-        (site, area_size) for site, area_size in sites if not has_coordinates(site) and has_boundary(site)
+        (site, area_size) for site, area_size in sites_run if not has_coordinates(site) and has_boundary(site)
     ]
     with_gadm_ids = [
-        (site, area_size) for site, area_size in sites if not has_coordinates(site) and not has_boundary(site)
+        (site, area_size) for site, area_size in sites_run if not has_coordinates(site) and not has_boundary(site)
     ]
 
     return {
         ParamType.COORDINATES: with_coordinates,
         ParamType.BOUNDARIES: with_boundaries,
         ParamType.GADM_IDS: with_gadm_ids
-    }
+    }, sites_no_run
 
 
 def _run(sites: list, years: list = [], years_only: bool = False):
     rasters = list_rasters(years=years, years_only=years_only)
     vectors = [] if years_only else list_vectors(sites)
-    filtered_data = _group_sites(sites, not years_only)
+    filtered_data, sites_no_run = _group_sites(sites, not years_only)
     return flatten([
         _run_values(filtered_data.get(param_type), param_type, rasters, vectors, years)
         for param_type in [e for e in ParamType] if len(filtered_data.get(param_type)) > 0
-    ])
+    ] + _run_values(sites_no_run, years=years))
+
+
+def _run_by_years(sites: list, years: list, batch_size: int):
+    batches = range(0, len(years), batch_size)
+
+    for batch_index in batches:
+        logger.info(f"Processing sites in batch {batch_index + 1} of {len(batches)}...")
+        sub_years = years[batch_index:batch_index + batch_size]
+        sites = _run(sites, sub_years, years_only=True)
+
+    return sites
 
 
 def run(sites: list, years: list = None):
@@ -141,12 +164,10 @@ def run(sites: list, years: list = None):
 
     # avoid memory limit errors by running only a few years at a time
     unique_years = sorted(list(set(years)))
-    batch_size = 5
-    batches = range(0, len(unique_years), batch_size)
 
-    for batch_index in batches:
-        logger.info(f"Processing sites in batch {batch_index + 1} of {len(batches)}...")
-        sub_years = unique_years[batch_index:batch_index + batch_size]
-        sites = _run(sites, sub_years, years_only=True)
-
-    return sites
+    try:
+        return _run_by_years(sites, unique_years, batch_size=5)
+    except Exception as e:
+        if 'exceeded' in str(e):
+            return _run_by_years(sites, unique_years, batch_size=1)
+        raise e
