@@ -41,8 +41,8 @@ RETURNS = {
 }
 LOOKUPS = {
     "@doc": "Different lookup files are used depending on the situation",
-    "ecoregion-siteType-LandTransformationChaudaryBrooks2018CF": "using `ecoregion`",
-    "region-siteType-LandTransformationChaudaryBrooks2018CF": "using `country`"
+    "ecoregion-siteType-LandTransformationChaudaryBrooks2018CF": "",
+    "region-siteType-LandTransformationChaudaryBrooks2018CF": ""
 }
 TERM_ID = 'damageToTerrestrialEcosystemsLandTransformation'
 
