@@ -1,15 +1,3 @@
-"""
-Calculates the EU PEF Abiotic resource depletion, for minerals and metals Indicator
-
-Uses lookup factors from [eplca.jrc.ec.europa.eu](https://eplca.jrc.ec.europa.eu/permalink/EF3_1/EF-LCIAMethod_CF(EF-v3.1).xlsx), Accessed 2024-09-05.
-
-> The results of this impact category shall be interpreted with caution, because the results of ADP after
-> normalization may be overestimated. The European Commission intends to develop a new method moving
-> from depletion to dissipation model to better quantify the potential for conservation of resources
-
-Source: [JRC Technical reports Suggestions for updating the Product Environmental Footprint (PEF) method](https://eplca.jrc.ec.europa.eu/permalink/PEF_method.pdf#%5B%7B%22num%22%3A80%2C%22gen%22%3A0%7D%2C%7B%22name%22%3A%22XYZ%22%7D%2C68%2C363%2C0%5D)
-"""  # noqa: E501
-
 from hestia_earth.schema import TermTermType
 from hestia_earth.utils.lookup import get_table_value, download_lookup, column_name
 from hestia_earth.utils.model import filter_list_term_type
@@ -95,7 +83,7 @@ def _should_run(impact_assessment: dict) -> tuple[bool, list]:
                     "indicator-input-is-valid": _valid_input(input),
                     "value": _node_value(resource_indicator),
                     "coefficient": get_table_value(
-                        array=download_lookup(filename=f"{input.get('termType')}.csv"),
+                        lookup=download_lookup(filename=f"{input.get('termType')}.csv"),
                         col_match='termid',
                         col_match_with=input.get('@id'),
                         col_val=column_name(LOOKUPS.get(input.get('termType'), ''))) if input else None
