@@ -1,9 +1,3 @@
-"""
-Completeness Soil Amendments
-
-This model checks if we have the requirements below and updates the
-[Data Completeness](https://hestia.earth/schema/Completeness#soilAmendment) value.
-"""
 from hestia_earth.models.log import logRequirements
 from hestia_earth.models.utils import is_from_model
 from hestia_earth.models.utils.measurement import measurement_value
