@@ -1,10 +1,3 @@
-"""
-End Date
-
-This model sets the [Cycle endDate](https://hestia.earth/schema/Cycle#endDate) based on:
-* if no `cycleDuration` is provided, and the `endDate` is set to month precision (e.g., `2000-01`),
-assumed it ended on the 14th of the month.
-"""
 from hestia_earth.utils.date import is_in_months
 
 from hestia_earth.models.log import logRequirements, logShouldRun
