@@ -1,16 +1,3 @@
-"""
-Input HESTIA Aggregated Data
-
-This model adds `impactAssessment` to inputs based on data which has been aggregated into country level averages.
-Note: to get more accurate impacts, we recommend setting the
-[input.impactAssessment](https://hestia.earth/schema/Input#impactAssessment)
-instead of the region-level averages using this model.
-
-For `seed` inputs, we will match ImpactAssessment in the following order of priority:
-- match using the value from the lookup `linkedImpactAssessmentTermId`;
-- match using the primary crop product;
-- match using the "generic" crop product term.
-"""
 from hestia_earth.schema import TermTermType
 from hestia_earth.utils.api import download_hestia
 from hestia_earth.utils.model import find_primary_product, linked_node, filter_list_term_type
