@@ -1,11 +1,6 @@
-"""
-Material and Substrate
-
-This model gap-fills depreciated amount per Cycle from Site Infrastructure node.
-"""
 from typing import Union
 from hestia_earth.schema import TermTermType
-from hestia_earth.utils.lookup import download_lookup
+from hestia_earth.utils.lookup import download_lookup, lookup_term_ids
 from hestia_earth.utils.tools import to_precision, flatten, list_sum
 from hestia_earth.utils.model import filter_list_term_type
 
@@ -100,14 +95,15 @@ def _run_input(cycle: dict, input_node: dict) -> dict:
 
 def _has_depreciated_term(term: dict):
     lookup = download_lookup(f"{term.get('termType')}.csv")
-    return term.get('@id') + _ID_SUFFIX in list(lookup.termid)
+    term_ids = lookup_term_ids(lookup)
+    return term.get('@id') + _ID_SUFFIX in term_ids
 
 
 def _should_run_input(cycle: dict, input_node: dict) -> bool:
     term = input_node.get('term', {})
     term_id = term.get('@id')
     has_lifespan = input_node.get('lifespan') or 0 > 0
-    has_valid_value = _get_value(input_node, 'value') > 0
+    has_valid_value = _get_value(input_node, 'value') or 0 > 0
     has_depreciated_term = _has_depreciated_term(term)
 
     should_run = all([
