@@ -1,13 +1,3 @@
-"""
-Milk Yield
-
-This model gap-fills the practice "Milk yield per animal X (raw/FPCM)" (e.g. `Milk yield per cow (raw)`) when:
-
-1. The corresponding milk term in the animalProduct glossary (e.g. Milk, cow, raw) is added as a Product of the Cycle;
-2. The number of lactating animals is known.
-
-It also adds the properties of the Product to the gap-filled Practice.
-"""
 from hestia_earth.schema import TermTermType, SiteSiteType, PracticeStatsDefinition
 from hestia_earth.utils.model import filter_list_term_type, find_term_match
 from hestia_earth.utils.tools import list_sum
