@@ -1,9 +1,3 @@
-"""
-Other Sites Area
-
-For animal production cycles, use the `stockingDensityAnimalHousingAverage` to calculate the average area required
-for all animals.
-"""
 from hestia_earth.schema import SiteSiteType
 
 from .siteArea import _is_site_valid, _should_run as _should_run_site, _run
