@@ -1,10 +1,3 @@
-"""
-Product Properties
-
-This model handles the following case:
-- when the `dryMatter` property is set, the model recalculates the other properties based on the data from feedipedia;
-- when the `min` and `max` are set, the model averages the `value`.
-"""
 from hestia_earth.utils.model import find_term_match
 
 from hestia_earth.models.utils.feedipedia import rescale_properties_from_dryMatter
