@@ -1,7 +1,3 @@
-"""
-Must be associated with at least 1 `Cycle` that has an
-[endDate](https://hestia.earth/schema/Cycle#endDate) after `1979-01-01` and before `2020-06-01`.
-"""
 from hestia_earth.schema import MeasurementMethodClassification
 from hestia_earth.utils.tools import non_empty_list
 
