@@ -1,16 +1,11 @@
-"""
-Land Cover
-
-This model calculates historic land use change over a twenty-year period,
-extending the functionality of the Blonk model.
-"""
+import functools
 import math
 from collections import defaultdict
 from datetime import datetime, timedelta
 
 from hestia_earth.schema import SiteSiteType, TermTermType
 from hestia_earth.utils.lookup import (
-    download_lookup, get_table_value, column_name, _is_missing_value, extract_grouped_data
+    download_lookup, get_table_value, column_name, _is_missing_value, extract_grouped_data, lookup_columns
 )
 from hestia_earth.utils.model import filter_list_term_type
 from hestia_earth.utils.tools import safe_parse_float, to_precision
@@ -19,6 +14,7 @@ from hestia_earth.models.log import logRequirements, log_as_table, logShouldRun
 from hestia_earth.models.utils.constant import DAYS_IN_YEAR
 from hestia_earth.models.utils.management import _new_management
 from hestia_earth.models.utils.term import get_lookup_value
+from hestia_earth.models.utils.lookup import get_region_lookup_value
 from hestia_earth.models.utils.blank_node import _node_date, DatestrFormat, _gapfill_datestr, DatestrGapfillMode
 from .utils import (
     IPCC_LAND_USE_CATEGORY_ANNUAL,
@@ -71,9 +67,9 @@ RETURNS = {
     }]
 }
 LOOKUPS = {
-    "region-crop-cropGroupingFaostatProduction-areaHarvestedUpTo20YearExpansion": "All crops",
-    "region-crop-cropGroupingFaostatProduction-areaHarvested": "All crops",
-    "region-faostatArea-UpTo20YearExpansion": "All land uses",
+    "region-crop-cropGroupingFaostatProduction-areaHarvestedUpTo20YearExpansion": "",
+    "region-crop-cropGroupingFaostatProduction-areaHarvested": "",
+    "region-faostatArea-UpTo20YearExpansion": "",
     "region-faostatArea": [
         "Arable land",
         "Cropland",
@@ -99,6 +95,27 @@ SITE_TYPES = {
 DEFAULT_WINDOW_IN_YEARS = 20
 DATE_TOLERANCE_IN_YEARS = 2
 OUTPUT_SIGNIFICANT_DIGITS = 3
+_LOOKUP_EXPANSION = "region-crop-cropGroupingFaostatProduction-areaHarvestedUpTo20YearExpansion.csv"
+
+
+def _get_lookup_with_cache(lookup_term, column):
+    """Wrapper to get_lookup_value which pulls out the immutable parts of the term to allow caching."""
+    @functools.cache
+    def _get_immutable_lookup(term_id: str, term_type: str, col: str):
+        new_term = {"@id": term_id, "termType": term_type} if term_type and term_id else {}
+        return get_lookup_value(
+            lookup_term=new_term,
+            column=col,
+            skip_debug=False,
+            model=MODEL,
+            term=new_term
+        )
+
+    return _get_immutable_lookup(
+        term_id=lookup_term.get("@id"),
+        term_type=lookup_term.get("termType"),
+        col=column
+    )
 
 
 def _management(term_id: str, value: float, start_date: str, end_date: str):
@@ -117,16 +134,34 @@ def _safe_divide(numerator, denominator, default=0) -> float:
     return default if not denominator else numerator / denominator
 
 
+def scale_values_to_one(dictionary: dict) -> dict:
+    """
+    Takes a dictionary with numeric values.
+    Scales each value so that the sum of them all is one.
+    """
+    # Does not handle negative values.
+    sum_of_values = sum(dictionary.values())
+    return {key: value / sum_of_values for key, value in dictionary.items()} if sum_of_values != 0 else dictionary
+
+
+def cap_values(dictionary: dict, lower_limit: float = 0, upper_limit: float = 1) -> dict:
+    return {key: min([upper_limit, max([lower_limit, value])]) for key, value in dictionary.items()}
+
+
 def site_area_sum_to_100(dict_of_percentages: dict):
-    return False if dict_of_percentages == {} else \
-        (math.isclose(sum(dict_of_percentages.values()), 1.0, rel_tol=0.01) or
-         math.isclose(sum(dict_of_percentages.values()), 0.0, rel_tol=0.01))
+    return False if dict_of_percentages == {} else (
+        math.isclose(sum(dict_of_percentages.values()), 1.0, rel_tol=0.01) or
+        math.isclose(sum(dict_of_percentages.values()), 0.0, rel_tol=0.01)
+    )
 
 
-def _should_group_landCover(term: dict):
+def _should_group_landCover(management_node: dict):
     return any(
-        bool(get_lookup_value(lookup_term=prop.get("term", {}), column="CALCULATE_TOTAL_LAND_COVER_SHARE_SEPARATELY"))
-        for prop in term.get("properties", [])
+        bool(_get_lookup_with_cache(
+            lookup_term=prop.get("term", {}),
+            column="CALCULATE_TOTAL_LAND_COVER_SHARE_SEPARATELY"
+        ))
+        for prop in management_node.get("properties", [])
     )
 
 
@@ -134,12 +169,13 @@ def get_changes(country_id: str, end_year: int) -> tuple[dict, bool]:
     """
     For each entry in ALL_LAND_USE_TERMS, creates a key: value in output dictionary, also TOTAL
     """
-    lookup = download_lookup("region-faostatArea-UpTo20YearExpansion.csv")
+    lookup_name = "region-faostatArea-UpTo20YearExpansion.csv"
     changes_dict = {
         land_use_term: safe_parse_float(
             extract_grouped_data(
-                get_table_value(lookup, 'termid', country_id, column_name(land_use_term)),
-                str(end_year)),
+                get_region_lookup_value(lookup_name, country_id, land_use_term, model=MODEL, key=MODEL_KEY),
+                str(end_year)
+            ),
             default=None
         )
         for land_use_term in ALL_LAND_USE_TERMS + [LAND_AREA]
@@ -160,8 +196,7 @@ def _get_ratio_start_and_end_values(
     end_year: int
 ) -> float:
     # expansion over twenty years / current area
-    lookup = download_lookup('region-faostatArea.csv')
-    table_value = get_table_value(lookup, 'termid', country_id, column_name(fao_name))
+    table_value = get_region_lookup_value('region-faostatArea.csv', country_id, fao_name, model=MODEL, key=MODEL_KEY)
     end_value = safe_parse_float(value=extract_grouped_data(table_value, str(end_year)), default=None)
     return max(0.0, _safe_divide(numerator=expansion, denominator=end_value))
 
@@ -186,11 +221,13 @@ def _estimate_maximum_forest_change(
 
 
 def _negative_agricultural_land_change(forest_change, pasture_change, total_cropland_change):
-    return -pasture_change if 0 < pasture_change < -min(forest_change, 0) \
-        else min(forest_change, 0) if pasture_change > 0 \
-        else -total_cropland_change if 0 < total_cropland_change < -min(forest_change, 0) \
-        else min(forest_change, 0) if 0 < total_cropland_change \
+    return (
+        -pasture_change if 0 < pasture_change < -min(forest_change, 0)
+        else min(forest_change, 0) if pasture_change > 0
+        else -total_cropland_change if 0 < total_cropland_change < -min(forest_change, 0)
+        else min(forest_change, 0) if 0 < total_cropland_change
         else 0
+    )
 
 
 def _allocate_forest_loss(forest_loss: float, changes: dict):
@@ -271,12 +308,14 @@ def _estimate_conversions_to_annual_cropland(
     permanent_to_annual_cropland: float
 ) -> dict:
     """(AC-AG): Estimate percentage of land sources when converted to: Annual cropland"""
+
     # -> percent_annual_cropland_was[]
     def conversion_to_annual_cropland(factor: float):
         return factor * _safe_divide(
             numerator=_safe_divide(
                 numerator=max(changes[ANNUAL_CROPLAND], 0),
-                denominator=max(changes[ANNUAL_CROPLAND], 0) + max(changes[PERMANENT_CROPLAND], 0)),
+                denominator=max(changes[ANNUAL_CROPLAND], 0) + max(changes[PERMANENT_CROPLAND], 0)
+            ),
             denominator=-changes[ANNUAL_CROPLAND]
         )
 
@@ -297,11 +336,13 @@ def _estimate_conversions_to_permanent_cropland(
     other_land_loss_to_annual_cropland: float
 ) -> dict:
     """Estimate percentage of land sources when converted to: Annual cropland"""
+
     def conversion_to_permanent_cropland(factor: float):
         return _safe_divide(
             numerator=_safe_divide(
                 numerator=factor * max(changes[PERMANENT_CROPLAND], 0),
-                denominator=max(changes[ANNUAL_CROPLAND], 0) + max(changes[PERMANENT_CROPLAND], 0)),
+                denominator=max(changes[ANNUAL_CROPLAND], 0) + max(changes[PERMANENT_CROPLAND], 0)
+            ),
             denominator=-changes[PERMANENT_CROPLAND]
         )
 
@@ -360,15 +401,15 @@ def _get_shares_of_expansion(
         PERMANENT_CROPLAND: percent_permanent_cropland_was,
         PERMANENT_PASTURE: percent_pasture_was
     }
-    return {
+    return scale_values_to_one({
         k: expansion_for_type[land_use_type].get(k, 0)
         for k in LAND_USE_TERMS_FOR_TRANSFORMATION.keys()
-    }
+    })
 
 
 def _get_faostat_name(term: dict) -> str:
     """For landCover terms, find the cropGroupingFaostatArea name for the landCover id."""
-    return get_lookup_value(term, "cropGroupingFaostatArea")
+    return _get_lookup_with_cache(term, "cropGroupingFaostatArea")
 
 
 def _get_complete_faostat_to_crop_mapping() -> dict:
@@ -391,10 +432,11 @@ def _get_harvested_area(country_id: str, year: int, faostat_name: str) -> float:
     """
     Returns a dictionary of harvested areas for the country & year, indexed by landCover term (crop)
     """
-    lookup = download_lookup("region-crop-cropGroupingFaostatProduction-areaHarvested.csv")
+    lookup_name = "region-crop-cropGroupingFaostatProduction-areaHarvested.csv"
+
     return safe_parse_float(
         value=extract_grouped_data(
-            data=get_table_value(lookup, "termid", country_id, column_name(faostat_name)),
+            data=get_region_lookup_value(lookup_name, country_id, faostat_name, model=MODEL, key=MODEL_KEY),
             key=str(year)
         ),
         default=None
@@ -452,8 +494,7 @@ def _run(site: dict, existing_nodes: list, percentage_transformed_from: dict):
 
 
 def get_ratio_of_expanded_area(country_id: str, fao_name: str, end_year: int) -> float:
-    lookup = download_lookup("region-crop-cropGroupingFaostatProduction-areaHarvestedUpTo20YearExpansion.csv")
-    table_value = get_table_value(lookup, 'termid', country_id, column_name(fao_name))
+    table_value = get_region_lookup_value(_LOOKUP_EXPANSION, country_id, fao_name, model=MODEL, key=MODEL_KEY)
     expansion = safe_parse_float(value=extract_grouped_data(table_value, str(end_year)), default=None)
     end_value = _get_harvested_area(
         country_id=country_id,
@@ -472,16 +513,16 @@ def _get_sum_for_land_category(
     fao_stat_to_ipcc_type: dict,
     include_negatives: bool = True
 ) -> float:
-    return sum(
-        [
-            safe_parse_float(value=extract_grouped_data(table_value, str(year)), default=None)
-            for fao_name, table_value in values.items()
-            if not _is_missing_or_none(extract_grouped_data(table_value, str(year))) and
-            fao_stat_to_ipcc_type[fao_name] == ipcc_land_use_category and
-            (include_negatives or
-             safe_parse_float(value=extract_grouped_data(table_value, str(year)), default=None) > 0.0)
-        ]
-    )
+    return sum([
+        safe_parse_float(value=extract_grouped_data(table_value, str(year)), default=None)
+        for fao_name, table_value in values.items()
+        if not _is_missing_or_none(extract_grouped_data(table_value, str(year))) and
+        fao_stat_to_ipcc_type[fao_name] == ipcc_land_use_category and
+        (
+            include_negatives or
+            safe_parse_float(value=extract_grouped_data(table_value, str(year)), default=None) > 0.0
+        )
+    ])
 
 
 def _get_sums_of_crop_expansion(country_id: str, year: int, include_negatives: bool = True) -> tuple[float, float]:
@@ -489,9 +530,12 @@ def _get_sums_of_crop_expansion(country_id: str, year: int, include_negatives: b
     Sum net expansion for all annual and permanent crops, returned as two values.
     Returns a tuple of (expansion of annual crops, expansion of permanent crops)
     """
-    lookup = download_lookup("region-crop-cropGroupingFaostatProduction-areaHarvestedUpTo20YearExpansion.csv")
-    values = {name: get_table_value(lookup, 'termid', country_id, column_name(name))
-              for name in list(lookup.dtype.names) if name != "termid"}
+    lookup = download_lookup(_LOOKUP_EXPANSION.replace('region', f"{country_id}")) or download_lookup(_LOOKUP_EXPANSION)
+    columns = lookup_columns(lookup)
+    values = {
+        name: get_region_lookup_value(lookup_name=_LOOKUP_EXPANSION, term_id=country_id, column=name, model=MODEL)
+        for name in columns if name != "termid"
+    }
 
     fao_stat_to_ipcc_type = _get_complete_faostat_to_crop_mapping()
 
@@ -513,8 +557,9 @@ def _get_sums_of_crop_expansion(country_id: str, year: int, include_negatives: b
     return annual_sum_of_expansion, permanent_sum_of_expansion
 
 
-def _get_net_expansion_cultivated_vs_harvested(annual_crops_net_expansion, changes, land_use_type,
-                                               permanent_crops_net_expansion):
+def _get_net_expansion_cultivated_vs_harvested(
+    annual_crops_net_expansion, changes, land_use_type, permanent_crops_net_expansion
+):
     if land_use_type == ANNUAL_CROPLAND:
         net_expansion_cultivated_vs_harvested = _safe_divide(numerator=max(0, changes[ANNUAL_CROPLAND]),
                                                              denominator=(annual_crops_net_expansion / 1000))
@@ -673,14 +718,14 @@ def _should_run_historical_land_use_change_single_crop(
 
     site_area = {
         land_type: (
-            shares_of_expansion[land_type] * expansion_factor * e9_net_expansion * net_expansion_cultivated_vs_harvested
-        )
-        for land_type in LAND_USE_TERMS_FOR_TRANSFORMATION.keys()
+           shares_of_expansion[land_type] * expansion_factor * e9_net_expansion * net_expansion_cultivated_vs_harvested
+        ) for land_type in LAND_USE_TERMS_FOR_TRANSFORMATION.keys()
         if land_type != land_use_type
     }
     site_area[land_use_type] = 1 - sum(site_area.values())
+    capped_site_area = cap_values(dictionary=site_area, lower_limit=0, upper_limit=1)
 
-    sum_of_site_areas_is_100 = site_area_sum_to_100(site_area)
+    sum_of_site_areas_is_100 = site_area_sum_to_100(capped_site_area)
     site_type_allowed = site.get("siteType") in SITE_TYPES
 
     logRequirements(
@@ -691,7 +736,7 @@ def _should_run_historical_land_use_change_single_crop(
         land_use_type=land_use_type,
         country_id=country_id,
         changes=log_as_table(changes),
-        site_area=log_as_table(site_area),
+        site_area=log_as_table(capped_site_area),
         sum_of_site_areas_is_100=sum_of_site_areas_is_100,
         site_type_allowed=site_type_allowed
     )
@@ -699,16 +744,11 @@ def _should_run_historical_land_use_change_single_crop(
     should_run = all([not missing_changes, country_id, site_type_allowed, sum_of_site_areas_is_100])
     logShouldRun(site, MODEL, term.get("@id"), should_run, model_key=MODEL_KEY)
 
-    return should_run, site_area
+    return should_run, capped_site_area
 
 
-def _get_land_use_term_from_node(node: dict) -> str:
-    return get_lookup_value(
-        lookup_term=node.get("term", {}),
-        column=LOOKUPS.get("landCover")[1],
-        model=MODEL,
-        term=node.get("term", {})
-    )
+def _get_land_use_term_from_node(node: dict):
+    return _get_lookup_with_cache(lookup_term=node.get("term", {}), column=LOOKUPS.get("landCover")[1])
 
 
 def _collect_land_use_types(nodes: list) -> list:
