@@ -1,14 +1,3 @@
-"""
-Creates an [emissionsResourceUse](https://hestia.earth/schema/Emission) for every landCover land transformation.
-contained within the [ImpactAssesment.cycle](https://hestia.earth/schema/ImpactAssessment#cycle), averaged over the last
-20 years.
-
-It does this by multiplying the land occupation during the cycle by the
-[Site](https://www-staging.hestia.earth/schema/Site) area 20 years ago and dividing by 20.
-
-Land transformation from [land type] 20 years =
-(Land occupation, during Cycle * Site Percentage Area 20 years ago [land type] / 100) / 20
-"""
 from .resourceUse_utils import run_resource_use
 
 REQUIREMENTS = {
