@@ -1,19 +1,8 @@
-"""
-Seed Emissions
-
-This model uses the `emissions` recalculated from the current `Cycle` to estimate the `emissions` associated with
-producing the `Input` with `termType` = `seed`.
-
-These are the steps:
-
-1. Recalculate all emissions for the Cycle of interest;
-2. Group Cycle emissions based on their `inputProductionGroupId` lookup value and sum them up;
-3. Divide the sum of each emission group by the average crop yield (from FAOSTAT) to get emissions per kg of product;
-4. Multiply by `seed.value` to get total background `emissions` from seed production per ha.
-"""
 from functools import reduce
 from hestia_earth.schema import TermTermType, EmissionMethodTier, SiteSiteType
-from hestia_earth.utils.lookup import download_lookup, column_name, get_table_value, extract_grouped_data_closest_date
+from hestia_earth.utils.lookup import (
+    download_lookup, column_name, extract_grouped_data_closest_date, find_term_ids_by
+)
 from hestia_earth.utils.model import filter_list_term_type
 from hestia_earth.utils.tools import non_empty_list, flatten, list_sum, safe_parse_float
 from hestia_earth.utils.emission import cycle_emissions_in_system_boundary
@@ -26,6 +15,7 @@ from hestia_earth.models.utils.cycle import cycle_end_year
 from hestia_earth.models.utils.crop import get_crop_grouping_faostat_production, get_landCover_term_id
 from hestia_earth.models.utils.completeness import _is_term_type_complete
 from hestia_earth.models.utils.blank_node import get_lookup_value
+from hestia_earth.models.utils.lookup import get_region_lookup_value
 from . import MODEL
 
 REQUIREMENTS = {
@@ -65,7 +55,7 @@ RETURNS = {
     }]
 }
 LOOKUPS = {
-    "region-crop-cropGroupingFaostatProduction-yield": "value from cropGroupingFaostatProduction and country",
+    "region-crop-cropGroupingFaostatProduction-yield": "",
     "crop": [
         "correspondingSeedTermIds",
         "cropGroupingFaostatProduction",
@@ -133,7 +123,7 @@ def _filter_emissions(cycle: dict):
             'id': group_id,
             'emissions': list(filter(
                 lambda id: id in required_emission_term_ids,
-                set(list(lookup[lookup[column_name('inputProductionGroupId')] == group_id].termid))
+                find_term_ids_by(lookup, column_name('inputProductionGroupId'), group_id)
             ))
         }
         for group_id in group_ids
@@ -169,11 +159,12 @@ def _evs(product: dict):
 
 def _faostat_yield(country_id: str, end_year: int, product: dict):
     grouping = get_crop_grouping_faostat_production(MODEL, product.get('term', {}))
-    return safe_parse_float(extract_grouped_data_closest_date(get_table_value(
-        download_lookup('region-crop-cropGroupingFaostatProduction-yield.csv'),
-        'termid',
+    return safe_parse_float(extract_grouped_data_closest_date(get_region_lookup_value(
+        'region-crop-cropGroupingFaostatProduction-yield.csv',
         country_id,
-        column_name(grouping)
+        grouping,
+        model=MODEL,
+        model_key=MODEL_KEY
     ), end_year))
 
 
