@@ -1,12 +1,3 @@
-"""
-Emissions
-
-Creates an [Indicator](https://hestia.earth/schema/Indicator) for every [Emission](https://hestia.earth/schema/Emission)
-contained within the [ImpactAssesment.cycle](https://hestia.earth/schema/ImpactAssessment#cycle).
-It does this by dividing the Emission amount by the Product amount, and applying an allocation between co-products.
-Note: for any Emission in the system boundary that does not exist in the Cycle, it will log the model as failed,
-so that we know the Emission is missing.
-"""
 from hestia_earth.utils.tools import list_sum
 from hestia_earth.utils.emission import cycle_emissions_in_system_boundary
 
