@@ -1,8 +1,3 @@
-"""
-Product Value
-
-Returns the [value](https://hestia.earth/schema/Product#value) of the Product linked to the Cycle.
-"""
 from hestia_earth.models.log import logShouldRun
 from hestia_earth.models.utils.product import find_by_product
 from .. import MODEL
