@@ -18,6 +18,7 @@ from hestia_earth.models.utils.array_builders import gen_seed
 from hestia_earth.models.utils.blank_node import group_nodes_by_year
 from hestia_earth.models.utils.descriptive_stats import calc_descriptive_stats
 from hestia_earth.models.utils.ecoClimateZone import EcoClimateZone, get_eco_climate_zone_value
+from hestia_earth.models.utils.source import get_source
 from hestia_earth.models.utils.measurement import _new_measurement
 
 from . import MODEL
@@ -87,6 +88,11 @@ RETURNS = {
     }]
 }
 TERM_ID = 'aboveGroundBiomass'
+BIBLIO_TITLE = '2019 Refinement to the 2006 IPCC Guidelines for National Greenhouse Gas Inventories'
+OTHER_BIBLIO_TITLES = [
+    '2006 IPCC Guidelines for National Greenhouse Gas Inventories',
+    'COMMISSION DECISION of 10 June 2010 on guidelines for the calculation of land carbon stocks for the purpose of Annex V to Directive 2009/28/EC'  # noqa: E501
+]
 
 _ITERATIONS = 10000
 _METHOD_CLASSIFICATION = MeasurementMethodClassification.TIER_1_MODEL.value
@@ -131,7 +137,7 @@ def run(site: dict) -> list[dict]:
         `aboveGroundBiomass`
     """
     should_run, inventory, kwargs = _should_run(site)
-    return _run(inventory, iterations=_ITERATIONS, **kwargs) if should_run else []
+    return _run(site, inventory, iterations=_ITERATIONS, **kwargs) if should_run else []
 
 
 def _should_run(site: dict) -> tuple[bool, dict, dict]:
@@ -407,6 +413,7 @@ the `dict` keys.
 
 
 def _run(
+    site: dict,
     inventory: dict,
     *,
     eco_climate_zone: EcoClimateZone,
@@ -501,7 +508,7 @@ def _run(
         axis=1,     # Calculate stats rowwise.
         decimals=6  # Round values to the nearest milligram.
     )
-    return [_measurement(timestamps, **descriptive_stats)]
+    return [_measurement(timestamps, **descriptive_stats) | get_source(site, BIBLIO_TITLE, OTHER_BIBLIO_TITLES)]
 
 
 def _build_col_name(biomass_category: BiomassCategory) -> str:
@@ -542,7 +549,7 @@ def _measurement(
     max : list[float]
         A list of maximum values representing the maximum modelled biomass stock for each year of the inventory.
     statsDefinition : str
-        The [statsDefinition](https://www-staging.hestia.earth/schema/Measurement#statsDefinition) of the measurement.
+        The [statsDefinition](https://hestia.earth/schema/Measurement#statsDefinition) of the measurement.
     observations : list[int]
         The number of model iterations used to calculate the descriptive statistics.
 
