@@ -17,7 +17,7 @@ REQUIREMENTS = {
     }
 }
 LOOKUPS = {
-    "region-liveAnimal-milkFatContent": "fat content",
+    "region-liveAnimal-milkFatContent": "",
     "liveAnimal": "milkYieldPracticeTermIds"
 }
 RETURNS = {
