@@ -20,7 +20,7 @@ REQUIREMENTS = {
     }
 }
 LOOKUPS = {
-    "region-liveAnimal-liveweightGain": "liveweight gain"
+    "region-liveAnimal-liveweightGain": ""
 }
 RETURNS = {
     "Animal": [{
