@@ -17,7 +17,7 @@ REQUIREMENTS = {
     }
 }
 LOOKUPS = {
-    "region-liveAnimal-milkTrueProteinContent": "protein content",
+    "region-liveAnimal-milkTrueProteinContent": "",
     "liveAnimal": "milkYieldPracticeTermIds"
 }
 RETURNS = {
