@@ -410,7 +410,7 @@ def create_should_run_function(
         cycle_end_date = cycle.get("endDate")
 
         site = _get_site(cycle)
-        cycles = related_cycles(site)
+        cycles = related_cycles(site, cycles_mapping={cycle_id: cycle})
 
         carbon_stock_measurements = [
             node for node in site.get("measurements", [])
