@@ -1,13 +1,3 @@
-"""
-Cycle Pasture Grass
-
-This model estimates the energetic requirements of ruminants and can be used to estimate the amount of grass they graze.
-Source:
-[IPCC 2019, Vol.4, Chapter 10](https://www.ipcc-nggip.iges.or.jp/public/2019rf/pdf/4_Volume4/19R_V4_Ch10_Livestock.pdf).
-
-This version of the model will run at the Cycle level, if at least one Cycle Input is given as feed
-(see https://www.hestia.earth/schema/Input#isAnimalFeed).
-"""
 from hestia_earth.schema import TermTermType
 from hestia_earth.utils.model import filter_list_term_type
 from hestia_earth.utils.tools import list_sum, non_empty_list
@@ -140,7 +130,7 @@ LOOKUPS = {
         "mjKgABNetEnergyGrowthSheepGoatsIpcc2019",
         "isWoolProducingAnimal"
     ],
-    "system-liveAnimal-activityCoefficient-ipcc2019": "using animal term @id",
+    "system-liveAnimal-activityCoefficient-ipcc2019": "",
     "landCover": "grazedPastureGrassInputId",
     "crop-property": ["energyDigestibilityRuminants", "energyContentHigherHeatingValue"],
     "crop": "grazedPastureGrassInputId",
