@@ -65,7 +65,7 @@ def logShouldRun(log_node: dict, model: str, term: Union[str, None], should_run:
 def debugMissingLookup(lookup_name: str, row: str, row_value: str, col: str, value, **kwargs):
     if value is None or value == '':
         extra = (', ' + _join_args(**kwargs)) if len(kwargs.keys()) > 0 else ''
-        logger.warning('Missing lookup=%s, %s=%s, column=%s' + extra, lookup_name, row, row_value, col)
+        logger.warning(f'Missing lookup={lookup_name}, {row}={row_value}, column={col}' + extra)
 
 
 def logErrorRun(model: str, term: str, error: str):
