@@ -8,10 +8,9 @@ import datetime
 from functools import reduce
 import operator
 from pydash.objects import get
-from typing import Any, Callable, Union
+from typing import Any, Callable
 from hestia_earth.schema import SchemaType
 from hestia_earth.utils.api import download_hestia
-from hestia_earth.utils.model import linked_node
 from hestia_earth.utils.tools import flatten, non_empty_list
 from hestia_earth.utils.date import is_in_days, is_in_months
 
@@ -44,20 +43,6 @@ def _omit(values: dict, keys: list) -> dict: return {k: v for k, v in values.ite
 def _include(value: dict, keys: list) -> dict: return {k: v for k, v in value.items() if k in keys}
 
 
-def _include_model(node: dict, term_id: str):
-    term = download_hestia(term_id) or {}
-    return {**node, **({} if term.get('@id') is None else {'model': linked_node(term)})}
-
-
-def _include_method(node: dict, term_id: Union[None, str, dict], key='method'):
-    term = (download_hestia(term_id) or {}) if isinstance(term_id, str) else term_id
-    return node | ({} if term is None or term.get('@id') is None else {key: linked_node(term)})
-
-
-def _include_methodModel(node: dict, term_id: str):
-    return _include_method(node, term_id=term_id, key='methodModel')
-
-
 def _run_in_serie(data: dict, models: list): return reduce(lambda prev, model: model(prev), models, data)
 
 
