@@ -12,38 +12,48 @@ from typing import (
     Optional,
     Union
 )
-
 from dateutil import parser
 from dateutil.relativedelta import relativedelta
 from hestia_earth.schema import TermTermType
-from hestia_earth.utils.api import download_hestia
 from hestia_earth.utils.blank_node import ArrayTreatment, get_node_value
 from hestia_earth.utils.model import filter_list_term_type
 from hestia_earth.utils.tools import (
     flatten,
     list_sum,
+    list_average,
     safe_parse_date,
     safe_parse_float,
     non_empty_list
 )
-
-from . import is_from_model, _filter_list_term_unit, is_iterable, full_date_str
-from .constant import Units, get_atomic_conversion
-from .lookup import (
+from hestia_earth.utils.lookup_utils import (
     is_model_siteType_allowed,
     is_siteType_allowed,
-    is_product_id_allowed, is_product_termType_allowed,
-    is_input_id_allowed, is_input_termType_allowed, _node_value
+    is_product_id_allowed,
+    is_product_termType_allowed,
+    is_input_id_allowed,
+    is_input_termType_allowed
 )
+
+from hestia_earth.models.log import debugValues, log_as_table
+from . import is_from_model, _filter_list_term_unit, is_iterable, full_date_str
+from .constant import Units, get_atomic_conversion
+from .lookup import _node_value
 from .property import get_node_property, get_node_property_value
-from .term import get_lookup_value
-from ..log import debugValues, log_as_table
+from .term import get_lookup_value, download_term
 
 # TODO: verify those values
 MAX_DEPTH = 1000
 OLDEST_DATE = '1800'
 
 
+def group_by_term(values: list):
+    def group_by(groups: dict, value: dict):
+        key = value.get('term', {}).get('@id')
+        groups[key] = groups.get(key, []) + [value]
+        return groups
+    return reduce(group_by, values, {})
+
+
 def merge_blank_nodes(source: list, new_values: list):
     """
     Merge a list of blank nodes into an existing list of blank nodes.
@@ -114,29 +124,29 @@ def _module_term_id(term_id: str, module):
     return getattr(module, 'TERM_ID', term_id_str).split(',')[0]
 
 
-def _run_model_required(model: str, term: dict, data: dict):
-    siteType_allowed = is_model_siteType_allowed(model, term, data)
+def _run_model_required(model: str, term_id: str, data: dict):
+    siteType_allowed = is_model_siteType_allowed(model, term_id, data)
 
     run_required = all([siteType_allowed])
-    debugValues(data, model=model, term=term.get('@id'),
+    debugValues(data, model=model, term=term_id,
                 run_required=run_required,
                 siteType_allowed=siteType_allowed)
     return run_required
 
 
-def _run_required(model: str, term: dict, data: dict):
-    siteType_allowed = is_siteType_allowed(data, term)
-    product_id_allowed = is_product_id_allowed(data, term)
-    product_termType_allowed = is_product_termType_allowed(data, term)
-    input_id_allowed = is_input_id_allowed(data, term)
-    input_termType_allowed = is_input_termType_allowed(data, term)
+def _run_required(model: str, term_id: str, data: dict):
+    siteType_allowed = is_siteType_allowed(data, term_id)
+    product_id_allowed = is_product_id_allowed(data, term_id)
+    product_termType_allowed = is_product_termType_allowed(data, term_id)
+    input_id_allowed = is_input_id_allowed(data, term_id)
+    input_termType_allowed = is_input_termType_allowed(data, term_id)
 
     run_required = all([
         siteType_allowed, product_id_allowed, product_termType_allowed, input_id_allowed, input_termType_allowed
     ])
     # model is only used for logs here, skip logs if model not provided
     if model:
-        debugValues(data, model=model, term=term.get('@id'),
+        debugValues(data, model=model, term=term_id,
                     siteType_allowed=siteType_allowed,
                     product_id_allowed=product_id_allowed,
                     product_termType_allowed=product_termType_allowed,
@@ -144,7 +154,7 @@ def _run_required(model: str, term: dict, data: dict):
                     input_termType_allowed=input_termType_allowed)
         # logging this for the model would cause issues parsing statuses
         if model != 'emissionNotRelevant':
-            debugValues(data, model=model, term=term.get('@id'), run_required=run_required)
+            debugValues(data, model=model, term=term_id, run_required=run_required)
     return run_required
 
 
@@ -166,10 +176,9 @@ def is_run_required(model: str, term_id: str, node: dict):
     bool
         True if the model is required to run.
     """
-    term = download_hestia(term_id)
     return (
-        (_run_model_required(model, term, node) if model else True) and _run_required(model, term, node)
-    ) if term else True
+        (_run_model_required(model, term_id, node) if model else True) and _run_required(model, term_id, node)
+    ) if term_id else True
 
 
 def run_if_required(model: str, term_id: str, data: dict, module):
@@ -1271,7 +1280,7 @@ def get_inputs_from_properties(input: dict, term_types: Union[TermTermType, List
     properties = (
         input.get('properties') or
         input.get('term', {}).get('defaultProperties') or
-        download_hestia(input.get('term', {}).get('@id')).get('defaultProperties')
+        download_term(input.get('term', {})).get('defaultProperties')
     )
     inputs = non_empty_list([
         {
@@ -1335,11 +1344,14 @@ def _node_from_group(nodes: list):
     # `nodes` contain list with consecutive dates
     return nodes[0] if len(nodes) == 1 else (
         # if all nodes have the same dates, sum up the values
-        nodes[0] | {'value': _sum_nodes_value(nodes)} if _same_dates(nodes)
-        else nodes[0] | {
-            'startDate': min(n.get('startDate') for n in nodes),
-            'endDate': max(n.get('endDate') for n in nodes)
-        }
+        nodes[0] | (
+            {
+                'value': _sum_nodes_value(nodes)
+            } if _same_dates(nodes) else {
+                'startDate': min(n.get('startDate') for n in nodes),
+                'endDate': max(n.get('endDate') for n in nodes)
+            }
+        )
     )
 
 
@@ -1349,7 +1361,7 @@ def _condense_nodes(nodes: list):
     return flatten(map(_node_from_group, grouped_nodes))
 
 
-def _group_nodes_to_condense(nodes: list) -> dict:
+def _group_nodes_by_value_and_properties(nodes: list) -> dict:
     def _group_node(group: dict, node: dict):
         value = node.get('value', [])
         value = '-'.join(map(str, value if isinstance(value, list) else [value]))
@@ -1359,7 +1371,6 @@ def _group_nodes_to_condense(nodes: list) -> dict:
                 f"{p.get('value')}"
             ])) for p in node.get('properties', [])
         ]))
-        # group by term, value, and properties
         group_key = '-'.join(non_empty_list([
             node.get('term', {}).get('@id', ''),
             value,
@@ -1371,8 +1382,51 @@ def _group_nodes_to_condense(nodes: list) -> dict:
     return reduce(_group_node, nodes, {})
 
 
+def _group_nodes_by_dates(nodes: list) -> dict:
+    def _group_node(group: dict, node: dict):
+        group_key = '-'.join(non_empty_list([
+            node.get('term', {}).get('@id', ''),
+            node.get('startDate'),
+            node.get('endDate'),
+        ]))
+        group[group_key] = group.get(group_key, []) + [node]
+        return group
+
+    return reduce(_group_node, nodes, {})
+
+
+def _average_properties(properties: list):
+    # group properties by term
+    grouped_properties = group_by_term(properties)
+    return [
+        props[0] | {
+            'value': list_average(non_empty_list([p.get('value') for p in props]), default=props[0].get('value'))
+        }
+        for props in grouped_properties.values()
+    ]
+
+
+def _merge_same_dates(nodes: list):
+    # group by term, startDate and endDate
+    grouped_nodes = _group_nodes_by_dates(nodes)
+
+    def merge_nodes(nodes: list):
+        properties = flatten([n.get('properties', []) for n in nodes])
+        return nodes[0] | (
+            {
+                'value': _sum_nodes_value(nodes)
+            } | ({
+                'properties': _average_properties(properties)
+            } if properties else {})
+        ) if len(nodes) > 1 else nodes[0]
+
+    return list(map(merge_nodes, grouped_nodes.values()))
+
+
 def condense_nodes(nodes: list) -> list:
-    grouped_nodes = _group_nodes_to_condense(nodes)
+    # merge nodes with the same term and dates as they need to be unique
+    values = _merge_same_dates(nodes)
+    grouped_nodes = _group_nodes_by_value_and_properties(values)
     return flatten(map(_condense_nodes, grouped_nodes.values()))
 
 
@@ -1446,13 +1500,13 @@ def most_relevant_blank_node_by_id(nodes: list, term_id: str, date: str):
 PROPERTY_UNITS_CONVERSIONS = {
     Units.KG.value: {
         Units.MJ.value: [
-            'energyContentHigherHeatingValue',  # "kg" to "mj"
+            'energyContentLowerHeatingValue',  # "kg" to "mj"
         ]
     },
     Units.M3.value: {
         Units.MJ.value: [
             'density',  # "m3" to "kg"
-            'energyContentHigherHeatingValue',  # "kg" to "mj"
+            'energyContentLowerHeatingValue',  # "kg" to "mj"
         ]
     }
 }
@@ -1506,7 +1560,6 @@ def convert_unit_properties(node_value: Union[int, float], node: dict, dest_unit
     Convert a number `node_value` belonging to a term `node`, to unit `to_units` by chaining multiple unit conversions
     together.
     Uses terms properties for the conversion.
-    Uses cached calls to download_hestia() internally for speedup
     Returns None if no conversion possible.
     """
     src_unit = node.get("units") or node.get('term', {}).get('units', "")
