@@ -1,9 +1,10 @@
 from hestia_earth.schema import CycleFunctionalUnit, SiteSiteType, TermTermType, AnimalReferencePeriod
 from hestia_earth.utils.model import filter_list_term_type, find_term_match, find_primary_product
 from hestia_earth.utils.tools import list_sum, safe_parse_float, safe_parse_date, non_empty_list
+from hestia_earth.utils.lookup_utils import is_siteType_allowed
 
 from ..log import logRequirements, debugValues
-from .lookup import all_factor_value, is_siteType_allowed
+from .lookup import all_factor_value
 from .term import get_lookup_value
 from .property import get_node_property
 from .completeness import _is_term_type_complete
@@ -344,7 +345,7 @@ def is_organic(cycle: dict):
         `True` if the `Cycle` is organic, `False` otherwise.
     """
     practices = filter_list_term_type(cycle.get('practices', []), TermTermType.STANDARDSLABELS)
-    return any([get_lookup_value(p.get('term', {}), 'isOrganic') == 'organic' for p in practices])
+    return next((get_lookup_value(p.get('term', {}), 'isOrganic') == 'organic' for p in practices), False)
 
 
 def is_irrigated(cycle: dict, **log_ars):
@@ -463,9 +464,9 @@ def get_animals_by_period(cycle: dict, period: AnimalReferencePeriod = AnimalRef
     ]
 
 
-def get_allowed_sites(model: str, term_id: str, termType: TermTermType, cycle: dict):
+def get_allowed_sites(model: str, term_id: str, cycle: dict):
     sites = non_empty_list([cycle.get('site', None)]) + cycle.get('otherSites', [])
-    allowed_sites = [s for s in sites if is_siteType_allowed(s, {'@id': term_id, 'termType': termType.value})]
+    allowed_sites = [s for s in sites if is_siteType_allowed(s, term_id)]
     allowed_site_ids = non_empty_list([s.get('@id', s.get('id')) for s in allowed_sites])
     debugValues(cycle, model=model, term=term_id, site_ids=';'.join(allowed_site_ids))
     return allowed_sites
