@@ -36,8 +36,8 @@ def get_eco_climate_zone_value(node: dict, as_enum: bool = False) -> Union[int,
     Parameters
     ----------
     node : dict
-        A HESTIA [Site](https://www-staging.hestia.earth/schema/Site) or
-        [Cycle](https://www-staging.hestia.earth/schema/Cycle).
+        A HESTIA [Site](https://hestia.earth/schema/Site) or
+        [Cycle](https://hestia.earth/schema/Cycle).
 
     Returns
     -------
