@@ -1,5 +1,9 @@
+from typing import Union
+from functools import lru_cache
+import json
 from hestia_earth.schema import SchemaType, TermTermType, SiteSiteType
-from hestia_earth.utils.api import find_node, search
+from hestia_earth.utils.storage import _load_from_storage
+from hestia_earth.utils.api import find_node, search, download_hestia
 from hestia_earth.utils.lookup import download_lookup, get_table_value, column_name
 
 from .constant import Units
@@ -20,6 +24,28 @@ def get_lookup_value(lookup_term: dict, column: str, skip_debug: bool = False, *
     return value
 
 
+@lru_cache()
+def _load_term_file(term_type: str):
+    try:
+        filepath = f"glossary/{term_type}.json"
+        nodes = json.loads(_load_from_storage(filepath, glossary=True))
+        return {node.get('@id'): node for node in nodes}
+    except Exception as e:
+        print(e)
+        return {}
+
+
+def download_term(term: Union[str, dict], termType: Union[str, TermTermType] = None):
+    term_id = term.get('@id', term.get('id')) if isinstance(term, dict) else term
+    term_type = (
+        termType if isinstance(termType, str) else termType.value
+    ) if termType else (
+        term.get('termType') if isinstance(term, dict) else None
+    )
+    cached_nodes = _load_term_file(term_type) if term_type else {}
+    return cached_nodes.get(term_id) or download_hestia(term_id)
+
+
 def get_liquid_fuel_terms():
     """
     Find all "liquid" `fuel` terms from the Glossary:
