@@ -11,7 +11,7 @@ from tests.utils import fake_new_emission, fixtures_path, order_list
 class_path = f"hestia_earth.models.{MODEL}.co2ToAirSoilOrganicCarbonStockChange"
 utils_path = f"hestia_earth.models.{MODEL}.co2ToAirCarbonStockChange_utils"
 soc_utils_path = f"hestia_earth.models.{MODEL}.organicCarbonPerHa_utils"
-soc_tier_1_utils_path = f"hestia_earth.models.{MODEL}.organicCarbonPerHa_tier_1_utils"
+soc_tier_1_utils_path = f"hestia_earth.models.{MODEL}.organicCarbonPerHa_tier_1"
 term_path = "hestia_earth.models.utils.term"
 fixtures_folder = f"{fixtures_path}/{MODEL}/co2ToAirSoilOrganicCarbonStockChange"
 
