@@ -10,8 +10,8 @@ from hestia_earth.models.ipcc2019.organicCarbonPerHa_utils import sample_constan
 from tests.utils import fake_new_measurement, fixtures_path
 
 class_path = f"hestia_earth.models.{MODEL}.{TERM_ID}"
-tier_1_utils_path = f"hestia_earth.models.{MODEL}.{TERM_ID}_tier_1_utils"
-tier_2_utils_path = f"hestia_earth.models.{MODEL}.{TERM_ID}_tier_2_utils"
+tier_1_utils_path = f"hestia_earth.models.{MODEL}.{TERM_ID}_tier_1"
+tier_2_utils_path = f"hestia_earth.models.{MODEL}.{TERM_ID}_tier_2"
 utils_path = f"hestia_earth.models.{MODEL}.{TERM_ID}_utils"
 term_path = "hestia_earth.models.utils.term"
 property_path = "hestia_earth.models.utils.property"
@@ -231,9 +231,9 @@ IDS_SHOULD_RUN = [p[0] for p in PARAMS_SHOULD_RUN]
 @patch(f"{utils_path}.get_cover_crop_property_terms", return_value=COVER_CROP_PROPERTY_TERM_IDS)
 @patch(f"{term_path}.search")
 @patch(f"{property_path}.find_term_property", side_effect=fake_find_term_property)
-@patch(f"{property_path}.download_hestia")
+@patch(f"{property_path}.download_term")
 def test_should_run(
-    download_hestia_mock: MagicMock,
+    download_term_mock: MagicMock,
     _find_term_property_mock: MagicMock,
     search_mock: MagicMock,
     _get_cover_crop_property_terms_mock: MagicMock,
@@ -263,15 +263,15 @@ def test_should_run(
     assert result == should_run
 
     # Ensure that the property and term utils are properly mocked.
-    download_hestia_mock.assert_not_called()
+    download_term_mock.assert_not_called()
     search_mock.assert_not_called()
 
 
 @patch(f"{tier_2_utils_path}.related_cycles", return_value=[])
 @patch(f"{term_path}.search")
-@patch(f"{property_path}.download_hestia")
+@patch(f"{property_path}.download_term")
 def test_should_run_no_data(
-    download_hestia_mock: MagicMock,
+    download_term_mock: MagicMock,
     search_mock: MagicMock,
     _related_cycles_mock: MagicMock
 ):
@@ -280,7 +280,7 @@ def test_should_run_no_data(
 
     result = run(SITE)
 
-    download_hestia_mock.assert_not_called()
+    download_term_mock.assert_not_called()
     search_mock.assert_not_called()
     assert result == EXPECTED
 
@@ -304,9 +304,9 @@ PARAMS_RUN = [subfolder for subfolder, should_run in PARAMS_SHOULD_RUN if should
 @patch(f"{utils_path}.get_cover_crop_property_terms", return_value=COVER_CROP_PROPERTY_TERM_IDS)
 @patch(f"{term_path}.search")
 @patch(f"{property_path}.find_term_property", side_effect=fake_find_term_property)
-@patch(f"{property_path}.download_hestia")
+@patch(f"{property_path}.download_term")
 def test_run(
-    download_hestia_mock: MagicMock,
+    download_term_mock: MagicMock,
     _find_term_property_mock: MagicMock,
     search_mock: MagicMock,
     _get_cover_crop_property_terms_mock: MagicMock,
@@ -346,7 +346,7 @@ def test_run(
     assert order_list(result) == order_list(expected)
 
     # Ensure that the property and term utils are properly mocked.
-    download_hestia_mock.assert_not_called()
+    download_term_mock.assert_not_called()
     search_mock.assert_not_called()
 
 
@@ -371,9 +371,9 @@ PARAMS_RUN_WITH_STATS = [
 @patch(f"{utils_path}.get_cover_crop_property_terms", return_value=COVER_CROP_PROPERTY_TERM_IDS)
 @patch(f"{term_path}.search")
 @patch(f"{property_path}.find_term_property", side_effect=fake_find_term_property)
-@patch(f"{property_path}.download_hestia")
+@patch(f"{property_path}.download_term")
 def test_run_with_stats(
-    download_hestia_mock: MagicMock,
+    download_term_mock: MagicMock,
     _find_term_property_mock: MagicMock,
     search_mock: MagicMock,
     _get_cover_crop_property_terms_mock: MagicMock,
@@ -409,5 +409,5 @@ def test_run_with_stats(
     assert order_list(result) == order_list(expected)
 
     # Ensure that the property and term utils are properly mocked.
-    download_hestia_mock.assert_not_called()
+    download_term_mock.assert_not_called()
     search_mock.assert_not_called()
