@@ -30,202 +30,42 @@ from hestia_earth.models.utils.blank_node import (
 
 
 class_path = "hestia_earth.models.utils.blank_node"
-measurement_fixtures_folder = f"{fixtures_path}/utils/measurement"
+fixtures_folder = os.path.join(fixtures_path, 'utils', 'blank_node')
+measurement_fixtures_folder = os.path.join(fixtures_path, 'utils', 'measurement')
 
-fixtures_path = os.path.join(fixtures_path, 'utils', 'blank_node')
+condense_fixtures_folder = os.path.join(fixtures_folder, 'condense-nodes')
+condense_folders = [
+    d for d in os.listdir(condense_fixtures_folder) if os.path.isdir(os.path.join(condense_fixtures_folder, d))
+]
 
 
-def test_condense_nodes():
-    with open(f"{fixtures_path}/condense-nodes/original.jsonld", encoding='utf-8') as f:
+@pytest.mark.parametrize('folder', condense_folders)
+def test_condense_nodes(folder: str):
+    fixture_path = os.path.join(condense_fixtures_folder, folder)
+
+    with open(f"{fixture_path}/original.jsonld", encoding='utf-8') as f:
         original = json.load(f)
-    with open(f"{fixtures_path}/condense-nodes/result.jsonld", encoding='utf-8') as f:
+    with open(f"{fixture_path}/result.jsonld", encoding='utf-8') as f:
         expected = json.load(f)
 
     value = condense_nodes(original)
-    assert value == expected
-
-
-@pytest.mark.parametrize(
-    "test_name,input_nodes,expected_output_nodes",
-    [
-        (
-            "No match",
-            [
-                {"startDate": "2001", "endDate": "2002", "term": {"@id": "treeNutTree", "units": "% area"},
-                 "value": [2]},
-                {"startDate": "2003", "endDate": "2004", "term": {"@id": "bananaPlant", "units": "% area"},
-                 "value": [2]},
-            ],
-            [
-                {"startDate": "2001", "endDate": "2002", "term": {"@id": "treeNutTree", "units": "% area"},
-                 "value": [2]},
-                {"startDate": "2003", "endDate": "2004", "term": {"@id": "bananaPlant", "units": "% area"},
-                 "value": [2]},
-            ],
-        ),
-        (
-            "No continuity",
-            [
-                {"startDate": "2001", "endDate": "2002", "term": {"@id": "treeNutTree", "units": "% area"},
-                 "value": [2]},
-                {"startDate": "2004", "endDate": "2005", "term": {"@id": "treeNutTree", "units": "% area"},
-                 "value": [2]},
-            ],
-            [
-                {"startDate": "2001", "endDate": "2002", "term": {"@id": "treeNutTree", "units": "% area"},
-                 "value": [2]},
-                {"startDate": "2004", "endDate": "2005", "term": {"@id": "treeNutTree", "units": "% area"},
-                 "value": [2]},
-            ],
-        ),
-        (
-            "No continuity (multiple values differ)",
-            [
-                {"startDate": "2001", "endDate": "2002", "term": {"@id": "treeNutTree", "units": "% area"},
-                 "value": [10, 20]},
-                {"startDate": "2003", "endDate": "2004", "term": {"@id": "treeNutTree", "units": "% area"},
-                 "value": [10, 30]},
-            ],
-            [
-                {"startDate": "2001", "endDate": "2002", "term": {"@id": "treeNutTree", "units": "% area"},
-                 "value": [10, 20]},
-                {"startDate": "2003", "endDate": "2004", "term": {"@id": "treeNutTree", "units": "% area"},
-                 "value": [10, 30]},
-            ],
-        ),
-        (
-            "2-1 condense (YYYY dates)",
-            [
-                {"startDate": "2001", "endDate": "2001", "term": {"@id": "treeNutTree", "units": "% area"},
-                 "value": [10, 20]},
-                {"startDate": "2002", "endDate": "2002", "term": {"@id": "treeNutTree", "units": "% area"},
-                 "value": [10, 20]},
-            ],
-            [
-                {"startDate": "2001", "endDate": "2002", "term": {"@id": "treeNutTree", "units": "% area"},
-                 "value": [10, 20]}
-            ],
-        ),
-        (
-            "4-2 condense (YYYY-MM dates)",
-            [
-                {"startDate": "2001-01", "endDate": "2002-01", "term": {"@id": "treeNutTree", "units": "% area"},
-                 "value": [2]},
-                {"startDate": "2002-01", "endDate": "2002-03", "term": {"@id": "treeNutTree", "units": "% area"},
-                 "value": [2]},
-            ],
-            [
-                {"startDate": "2001-01", "endDate": "2002-03", "term": {"@id": "treeNutTree", "units": "% area"},
-                 "value": [2]}
-            ],
-        ),
-        (
-            "2-1 condense (YYYY-MM-DD dates)",
-            [
-                {"startDate": "2001-01-01", "endDate": "2001-12-31", "term": {"@id": "treeNutTree", "units": "% area"},
-                 "value": [2]},
-                {"startDate": "2002-01-01", "endDate": "2002-05-04", "term": {"@id": "treeNutTree", "units": "% area"},
-                 "value": [2]},
-            ],
-            [
-                {"startDate": "2001-01-01", "endDate": "2002-05-04", "term": {"@id": "treeNutTree", "units": "% area"},
-                 "value": [2]}
-            ],
-        ),
-        (
-            "3-1-condense",
-            [
-                {"startDate": "2001-01-01", "endDate": "2001-12-31", "term": {"@id": "bananaPlant", "units": "% area"},
-                 "value": [9]},
-                {"startDate": "2002-01-01", "endDate": "2002-10-31", "term": {"@id": "bananaPlant", "units": "% area"},
-                 "value": [9]},
-                {"startDate": "2002-11-01", "endDate": "2004-04-05", "term": {"@id": "bananaPlant", "units": "% area"},
-                 "value": [9]},
-            ],
-            [
-                {"startDate": "2001-01-01", "endDate": "2004-04-05", "term": {"@id": "bananaPlant", "units": "% area"},
-                 "value": [9]}
-            ],
-        ),
-        (
-            "3-2-partial-condense",
-            [
-                {"startDate": "2001-01-01", "endDate": "2001-12-31", "term": {"@id": "bananaPlant", "units": "% area"},
-                 "value": [9]},
-                {"startDate": "2012-02-01", "endDate": "2012-12-31", "term": {"@id": "bananaPlant", "units": "% area"},
-                 "value": [9]},
-                {"startDate": "2002-01-01", "endDate": "2003-12-31", "term": {"@id": "bananaPlant", "units": "% area"},
-                 "value": [9]},
-            ],
-            [
-                {"startDate": "2001-01-01", "endDate": "2003-12-31", "term": {"@id": "bananaPlant", "units": "% area"},
-                 "value": [9]},
-                {"startDate": "2012-02-01", "endDate": "2012-12-31", "term": {"@id": "bananaPlant", "units": "% area"},
-                 "value": [9]},
-            ],
-        ),
-        (
-            "7-2-multi-condense",
-            [
-                {"startDate": "2001-01-01", "endDate": "2001-11-30", "term": {"@id": "bananaPlant", "units": "% area"},
-                 "value": [7]},
-                {"startDate": "2012-02-01", "endDate": "2012-12-31", "term": {"@id": "bananaPlant", "units": "% area"},
-                 "value": [7]},
-                {"startDate": "2001-12-01", "endDate": "2001-12-31", "term": {"@id": "bananaPlant", "units": "% area"},
-                 "value": [7]},
-                {"startDate": "2002-01-01", "endDate": "2002-12-31", "term": {"@id": "bananaPlant", "units": "% area"},
-                 "value": [7]},
-                {"startDate": "2013-01-01", "endDate": "2013-05-20", "term": {"@id": "bananaPlant", "units": "% area"},
-                 "value": [7]},
-            ],
-            [
-                {"startDate": "2001-01-01", "endDate": "2002-12-31", "term": {"@id": "bananaPlant", "units": "% area"},
-                 "value": [7]},
-                {"startDate": "2012-02-01", "endDate": "2013-05-20", "term": {"@id": "bananaPlant", "units": "% area"},
-                 "value": [7]}
-            ],
-        ),
-        (
-            "same-blank-nodes-sum",
-            [
-                {"startDate": "2001-01-01", "endDate": "2001-11-30", "term": {"@id": "bananaPlant", "units": "% area"},
-                 "value": [50]},
-                {"startDate": "2001-01-01", "endDate": "2001-11-30", "term": {"@id": "bananaPlant", "units": "% area"},
-                 "value": [50]}
-            ],
-            [
-                {"startDate": "2001-01-01", "endDate": "2001-11-30", "term": {"@id": "bananaPlant", "units": "% area"},
-                 "value": [100]}
-            ]
-        )
-    ]
-)
-def test_condense_nodes_(test_name, input_nodes, expected_output_nodes):
-    assert condense_nodes(input_nodes) == expected_output_nodes
+    assert value == expected, folder
 
 
 def test_run_required():
-    term = {
-        '@id': 'ch4ToAirAquacultureSystems',
-        'termType': 'emission'
-    }
-    assert not _run_required('model', term, {
+    assert not _run_required('model', 'ch4ToAirAquacultureSystems', {
         'site': {'siteType': SiteSiteType.CROPLAND.value}
     })
-    assert _run_required('model', term, {
+    assert _run_required('model', 'ch4ToAirAquacultureSystems', {
         'site': {'siteType': SiteSiteType.POND.value}
     }) is True
 
 
 def test_run_model_required():
-    term = {
-        '@id': 'netPrimaryProduction',
-        'termType': 'measurement'
-    }
-    assert _run_model_required('pooreNemecek2018', term, {
+    assert _run_model_required('pooreNemecek2018', 'netPrimaryProduction', {
         'site': {'siteType': SiteSiteType.POND.value}
     }) is True
-    assert not _run_model_required('pooreNemecek2018', term, {
+    assert not _run_model_required('pooreNemecek2018', 'netPrimaryProduction', {
         'site': {'siteType': SiteSiteType.CROPLAND.value}
     })
 
